
;*************************************************************************************** 
; Toon Image script  for GIMP 2.6
; Version 1.0.1 - 17-12-2010 added halftone option, check for existence of GREYCstoration
;                            pop up message only.  Filter continues if non-existent. 
;                            Added G'MIC support as per forum request.
; Version 1.0.2 - 17-12-2010 Re-did the Half-tone the same as the comic strip effect
;                            Copyright (C) 2019 John Harris john@grynn.com>  
;                            Based on comic-book script by Joe Kitella <joe.kitella@gmail.com
; Version 1.0.3 - 17-12-2010 Revised Halftone effect again... Coding problem with layers.
; 12-2011: 2.7 compatibility by F. Collard
; ---------------------------------------------------------------------------------------


(define (script-fu-CarTOONize
			img
			drawable
                        Prefilter
                        line-size
                        enable-shadow
                        shadow-intensity
                        half-tone
	)

  (gimp-image-undo-group-start img)

  (let* (
	 (width (car (gimp-drawable-width drawable)))
	 (height (car (gimp-drawable-height drawable)))
	 (old-selection (car (gimp-selection-save img)))
	 (image-type (car (gimp-image-base-type img)))
	 (layer-temp1 (car (gimp-layer-new img width height 0 "temp1"  100 NORMAL-MODE)))
	 (layer-temp2 (car (gimp-layer-new img width height 0 "temp2"  100 NORMAL-MODE)))
	 (layer-temp3 (car (gimp-layer-new img width height 0 "temp3"  100 NORMAL-MODE)))
	 (layer-temp2a (car (gimp-layer-new img width height 0 "temp2a"  100 NORMAL-MODE)))
	 (layer-temp4 (car (gimp-layer-new img width height 0 "temp4"  100 NORMAL-MODE)))
	 (layer-temp5 (car (gimp-layer-new img width height 0 "temp5"  100 NORMAL-MODE)))
	 (layer-temp6 (car (gimp-layer-new img width height 0 "temp6"  100 NORMAL-MODE)))
	 (layer-temp7 (car (gimp-layer-new img width height 0 "temp7"  100 NORMAL-MODE)))
 	 (layer-gmic (car (gimp-layer-new img width height 0 "gmic"  100 NORMAL-MODE)))
 	 (layer-comic (car (gimp-layer-new img width height 0 "Comic-strip"  100 NORMAL-MODE)))
     
         (isfiltered  FALSE)
      ) 

    (if (eqv? (car (gimp-selection-is-empty img)) TRUE)
        (gimp-drawable-fill old-selection WHITE-IMAGE-FILL)) ; so Empty and All are the same.
    (gimp-image-insert-layer img layer-gmic 0 -1)
    (gimp-image-insert-layer img layer-temp7 0 -1) 
    (gimp-image-insert-layer img layer-temp6 0 -1) 
    (gimp-image-insert-layer img layer-temp5 0 -1)
    (gimp-image-insert-layer img layer-temp4 0 -1)
    (gimp-image-insert-layer img layer-temp3 0 -1)

    (if (= enable-shadow TRUE)
        (begin
           (gimp-image-insert-layer img layer-temp2a 0 -1)
           (gimp-layer-set-mode layer-temp2a 3)
        )
    )

    (gimp-image-insert-layer img layer-temp1 0 -1)
    (gimp-image-insert-layer img layer-temp2 0 -1)
    (gimp-levels-stretch drawable)
    (gimp-edit-copy drawable)
    (gimp-floating-sel-anchor (car (gimp-edit-paste layer-gmic 0)))

    (if (= Prefilter TRUE)
      (if (defined? 'plug-in-greycstoration)
        (begin
          (plug-in-greycstoration 1 img layer-gmic 60 .70 1 .6 1.1 .8 30 2 0 0 4 10 15 7 1 2)
          (set! isfiltered TRUE)
        )  
      )    
    )         
    (if (= Prefilter TRUE)
      (if (= isfiltered FALSE)
        (if (defined? 'plug-in-gmic)
          (begin
            (plug-in-gmic 1 img layer-gmic 1 "-gimp_anisotropic_smoothing 60,.7,1,1.1,1,1,30,2,0,1,1,1,1")
            (set! isfiltered TRUE)
          )
         )  
       )
    )

    (gimp-edit-copy (car (gimp-image-get-active-layer img)))

    (gimp-floating-sel-anchor (car (gimp-edit-paste layer-temp1 0)))
    (gimp-floating-sel-anchor (car (gimp-edit-paste layer-temp3 0)))
    (gimp-floating-sel-anchor (car (gimp-edit-paste layer-temp4 0)))
    (gimp-floating-sel-anchor (car (gimp-edit-paste layer-temp7 0)))
    (if (= enable-shadow TRUE)
        (begin
           (gimp-floating-sel-anchor (car (gimp-edit-paste layer-temp2a 0)))
           (gimp-desaturate-full layer-temp2a 2)
           (gimp-threshold layer-temp2a shadow-intensity 255)
        )
    )
    (gimp-layer-set-mode layer-temp3 15)
    (gimp-layer-set-mode layer-temp5 15)
    (gimp-layer-set-mode layer-temp4 3)
    (gimp-layer-set-mode layer-temp6 3)
    (gimp-layer-set-mode layer-temp2 16)
    (gimp-desaturate-full layer-temp3 2)
    (gimp-edit-copy layer-temp1)
    (gimp-floating-sel-anchor (car (gimp-edit-paste layer-temp2 0)))
    
    (plug-in-gauss 1 img layer-temp2 line-size line-size 1)
    (gimp-invert layer-temp2)
    (gimp-image-merge-down img layer-temp2 0)
   
    (set! layer-temp1 (car (gimp-image-get-active-layer img)))
    (gimp-threshold layer-temp1 245 255)
    (gimp-layer-set-mode layer-temp1 0)
    (gimp-image-select-item img CHANNEL-OP-ADD old-selection)
    (gimp-selection-invert img)
    (if (eqv? (car (gimp-selection-is-empty img)) FALSE) 
        (begin
        (gimp-edit-clear layer-temp1)
        ))

    (gimp-layer-set-mode layer-temp1 3)
    (gimp-image-merge-down img layer-temp3 0)
    (set! layer-temp4 (car (gimp-image-get-active-layer img)))
    (gimp-edit-copy layer-temp4)
    (gimp-floating-sel-anchor (car (gimp-edit-paste layer-temp5 0)))
    (gimp-floating-sel-anchor (car (gimp-edit-paste layer-temp6 0)))
    (gimp-desaturate-full layer-temp5 2)
    (gimp-image-merge-down img layer-temp5 0)
    (set! layer-temp4 (car (gimp-image-get-active-layer img)))
    (gimp-layer-set-mode layer-temp4 3)
    (gimp-image-raise-item img layer-temp4)
    (gimp-image-merge-down img layer-temp4 0)
    (set! layer-temp6 (car (gimp-image-get-active-layer img)))
    (gimp-layer-set-mode layer-temp6 14)
    (gimp-image-merge-down img layer-temp6 0)
    (set! layer-temp7 (car (gimp-image-get-active-layer img)))

    (gimp-image-flatten img)
    (gimp-image-remove-channel img old-selection)

    (gimp-image-convert-indexed img 0 0 16 0 0 "")
    (gimp-image-convert-rgb img)
    (set! layer-temp1 (car (gimp-image-get-active-layer img)))

    (if (= half-tone TRUE)
     (begin
       (gimp-image-insert-layer img layer-comic 0 -1)
       (gimp-edit-copy layer-temp1)
       (gimp-floating-sel-anchor (car (gimp-edit-paste layer-comic 0)))
;       (gimp-hue-saturation layer-comic 0 0 0 100)
;       (gimp-posterize layer-comic 3) 
       (plug-in-unsharp-mask 0 0 layer-comic 4 10 0)
       (plug-in-newsprint 0 0 layer-comic 0 1 20 1 0 15 0 75 0 0 0 1)
      )
    )    
    (gimp-image-undo-group-end img)
    (gimp-displays-flush)
  )
)

(script-fu-register
  "script-fu-CarTOONize"
  _"<Image>/Filters/Artistic/CarTOONize"
  "Toon a Picture.  Take a standard RGB or Grayscale picture, and cartoonize it.  You can adjust the thickness of the lines, as well as adjust the 'black' shadow intensity.  Prefilter option requires and uses either the GREYCstoration Filter or the newer G'MIC Filter installed, (not included).  Set it to FALSE if you don't want noise reduction."
  "Joe1GK <kgioj@yahoo.com>"
  "Joe1GK"
  "2010, December"
  "RGB* GRAY*"
  SF-IMAGE      "Image"	                     0
  SF-DRAWABLE   "Drawable"                   0
  SF-TOGGLE     _"Prefilter (Surface Blur-GREYCstoration or G'MIC Filter Required *No progress indicator with G'MIC)" TRUE
  SF-ADJUSTMENT _"Line Thickness (pixels)"   '(10 2 30 1 10 0 1)
  SF-TOGGLE     _"Black Shadows"             TRUE
  SF-ADJUSTMENT _"Shadow Intensity"          '(35 0 50 1 10 0 1)
  SF-TOGGLE     _"Halftone"	             FALSE

)


