; 
; This program is free software; you can redistribute it and/or modify
; it under the terms of the GNU General Public License as published by
; the Free Software Foundation; either version 2 of the License, or
; (at your option) any later version.  
; 
; This program is distributed in the hope that it will be useful,
; but WITHOUT ANY WARRANTY; without even the implied warranty of
; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
; GNU General Public License for more details.
; 
; You should have received a copy of the GNU General Public License
; along with this program; if not, write to the Free Software
; Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
;
; Julia Jomantaite 20.04.2008"
; Modified by Franois Collard 6.7.2012


(define (script-fu-Orton-Effect inImage inLayer inBlur inOpacity 5on sll klayer)
	(gimp-image-undo-group-start inImage)
	
    ;Read the image width and height
	(define imageWidth (car (gimp-image-width inImage)))
	(define imageHeight (car (gimp-image-height inImage)))	
	
    ;Set blur factor to 5% of the shortest side
    (if (= 5on TRUE)
    (begin
        (if (> imageHeight imageWidth) (set! inBlur (/ imageWidth 20)) (set! inBlur (/ imageHeight 20))
        )
    )
    )

	(define (copy-and-add-layer orig-layer)
		(let  ((layer (car (gimp-layer-copy orig-layer TRUE))))
		(gimp-image-add-layer inImage layer -1)
		layer
		)
	)

	(define (create-light-layer orig-layer) 
        	(let  ((layer (copy-and-add-layer orig-layer)))
		      (gimp-layer-set-mode layer SCREEN-MODE)
		      (car (gimp-image-merge-down inImage layer CLIP-TO-BOTTOM-LAYER))
		)
	)

	(let*	(
		(layer (create-light-layer
;			     (if (= inKeepOriginal TRUE)
				 (copy-and-add-layer inLayer)
			    	 inLayer))
		(layer2 (copy-and-add-layer layer))
		)
		
;sharpen layer
	(if (= sll TRUE)
	    (plug-in-unsharp-mask 1 inImage layer 5 1 0)
	)
		
	(if (> inBlur 0)
		(plug-in-gauss 1 inImage layer2 inBlur inBlur 0)
	)
		(gimp-layer-set-mode layer2 MULTIPLY-MODE)
		(gimp-layer-set-opacity layer2 inOpacity)
		
	(if (= klayer FALSE)
	(gimp-image-flatten inImage)
	)
	)
	(gimp-image-undo-group-end inImage)
	(gimp-displays-flush)
)
;
(script-fu-register "script-fu-Orton-Effect"
	"<Image>/Filters/Artistic/Orton Effect"
	"Imitates Orton effect by creating two \
lighter layers from the original - \
one blurred and one sharp, and mixing them.\
Description of this method: http://pcin.net/update/2006/11/01/the-orton-effect-digital-photography-tip-of-the-week"
	"Julia Jomantaite <julia.jomantaite@gmail.com>"
	"Julia Jomantaite"
	"20.04.2008"
	"RGB* GRAY*"
	SF-IMAGE	"Image"	  		0
	SF-DRAWABLE	"Layer"			0
	SF-ADJUSTMENT	"Blur radius"	'(100 5 10000 1 10 0 1)
	SF-ADJUSTMENT	"Opacity"		'(90 0 100 1 10 1 0)
    SF-TOGGLE       "Set radus as 5% of shortest side"	TRUE
	SF-TOGGLE		"Sharpen lightest layer"	TRUE
	SF-TOGGLE       "Keep layers"	TRUE
)

