; Last changed 2011/11/09 by Franois Collard (fix error messages in Gimp 2.7-2.8)
; Simple color boost
;
; (C) 2011 Franois Collard
;
; Simple Color boost
;	Duplicaates background on a new layer
;	sets it to Overlay mode with a BW mask
;	which is a blurred copy of the image.

; Acknowledgements:
;   script-fu-template by Simon Budig
;   script-fu simple contrast mask by Andrew Robinson.
;   This script-fu was built using it as a template.

; Script-fu definition of varibles
; The script works on the background layer of the current
; image. There are no user input variables
;
; image - the current image
; calque-actif - the background layer
; largeur, hauteur - width and height of current image.
; blur-radius - the radius for the Gausian blur. Calculated as
; one percent of the shorter of the width or height
; color-boost - the overlayed layer.
; masque - the desaturated blurred mask
; An options dialog box could be easily added, but it was just useless
; for me. In some cases, you can:
; - Invert the mask
; - Increase/decrease mask contrast and lightness
; then, just flatten the image. The script only automates the most
; boring parts of the job:
; - duplicate layer
; - add a mask that is a BW copy of the layer
; - blur this mask
; - set layer to overlay.

(define (script-fu-simple-color-boost image drawable)

    ; Local variables

    (let* (
        (calque-actif (car  (gimp-image-get-active-drawable image)))
		(largeur  (car  (gimp-drawable-width calque-actif)))
        (hauteur (car  (gimp-drawable-height calque-actif)))
        (blur-radius (quotient largeur 100))
        (if (< hauteur largeur) (blur-radius (quotient hauteur 100)))
        (color-boost (car (gimp-layer-copy calque-actif TRUE)))
		(masque (car (gimp-layer-create-mask color-boost ADD-COPY-MASK)))
        )

        ; Preserve the original context

        (gimp-context-push)

        ; Enable UNDO
         (gimp-image-undo-group-start image)

        ; Copy the background layer and add it to the
        ; image just above that layer
		; add a mask that is a blurred desaturated copy of the layer

        (gimp-image-insert-layer image color-boost 0 0)
		(gimp-item-set-name color-boost "Color boost")
		(gimp-layer-add-mask color-boost masque)
               
        ;(gimp-invert masque)
        (plug-in-gauss-iir 1 image masque blur-radius 1 1)
        (gimp-layer-set-mode color-boost OVERLAY-MODE)
        ;(gimp-layer-set-opacity masque 75)

        ; End undo group
        (gimp-image-undo-group-end image)

        ; Restore the context saved earlier again.

        (gimp-context-pop)

        ; finally we notify the UI that something has changed.

        (gimp-displays-flush)
    )
)

; Register the script

(script-fu-register "script-fu-simple-color-boost"
		    "Color booster"
		    "Adds an overlay mask to enhance contrast and saturation"
		    "Franois Collard <francois.collard@free.fr>"
		    "Copyright 2011 Franois Collard"
		    "2011-05-05"
		    "RGB* GRAY*"
		    SF-IMAGE "Input Image" 0
		    SF-DRAWABLE "Input Drawable" 0
)

(script-fu-menu-register "script-fu-simple-color-boost" "<Image>/Colors")

