; The GIMP -- an image manipulation program
; Copyright (C) 1995 Spencer Kimball and Peter Mattis
; 
; This program is free software; you can redistribute it and/or modify
; it under the terms of the GNU General Public License as published by
; the Free Software Foundation; either version 2 of the License, or
; (at your option) any later version.
; 
; This program is distributed in the hope that it will be useful,
; but WITHOUT ANY WARRANTY; without even the implied warranty of
; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
; GNU General Public License for more details.
; 
; You should have received a copy of the GNU General Public License
; along with this program; if not, write to the Free Software
; Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
;
; Copyright (C) 2009 Dominic Chomko <dominic.chomko@gmail.com>
;
; This is a fast hack of Dominic Chomko's vignette script, to illustrate 
; a Gimp Users discussion.
;
; Usage: 
;
; - Creates a vignette based on the selection and active layer.
;
; - The blur radius, opacity, and colour can be set in the dialog box.
;
; - The script merges visible layers so check "Keep Layers" if you have multiple
;   Layers visible or to adjust vignette opacity or other settings.
;
;

(define (script-fu-vignetage inImage inLayer inRadius inOpacity inColour inBoolLayers)
  (let*
    	( 
		;variables

		(theImage (car (gimp-item-get-image inLayer) ) )
		(theWidth (car (gimp-image-width theImage) ) )
		(theHeight (car (gimp-image-height theImage) ) )
		(theRadius (* inRadius (/ (max theWidth theHeight) 25) ) )
		(vignetteLayer1
		  (car
			(gimp-layer-new
		 	  theImage
		 	  theWidth
		 	  theHeight
		 	  RGB-IMAGE
		 	  "Vignette Layer 1"
		 	  inOpacity
		 	  NORMAL
			)
		  )
		)	
	) ;end define variables

	(gimp-image-undo-group-start theImage)
	(gimp-context-set-foreground inColour)
	(gimp-context-set-background '(255 255 255))
	(gimp-drawable-fill
	  vignetteLayer1
	  FOREGROUND-FILL
	)
	(gimp-image-insert-layer
	  theImage
	  vignetteLayer1
	  0
	  0
	)

	(gimp-edit-fill
	  vignetteLayer1
	  WHITE-FILL
	)
	(plug-in-colortoalpha 1 theImage vignetteLayer1 '(255 255 255))
	(gimp-selection-none theImage)
	(if (> inRadius 0)
	  ( begin
		(plug-in-gauss-iir
		  RUN-NONINTERACTIVE
		  theImage
		  vignetteLayer1
		  theRadius
		  TRUE
		  TRUE
		)
	  )
	)
	(if (= inBoolLayers FALSE)
	  ( begin
		(gimp-image-merge-visible-layers
		  theImage
		  EXPAND-AS-NECESSARY
		)
	  )
	)


	(gimp-image-undo-group-end theImage)
	(gimp-displays-flush)
   
  )
)


(script-fu-register
                  "script-fu-vignetage"
                  "Vignetage"
                  "Creates a vignette around selection."
                  "-"
                  "-"
                  "December 9, 2011"
                  "*"
                  SF-IMAGE	"Input Image"		0
		  SF-DRAWABLE	"Input Selection"	0
		  SF-ADJUSTMENT	"Softness"		'(8 0 30 .1 1 1 0)
		  SF-ADJUSTMENT	"Darkness"		'(50 0 100 1 5 0 0)
		  SF-COLOR	"Colour"		'(0 0 0)
		  SF-TOGGLE	"Keep Layers"		TRUE
)
        
(script-fu-menu-register "script-fu-vignetage" "<Image>/Filters/Light and Shadow")
